==> sra-sdk_3.0.3+dfsg.orig.tar.xz: sra-tools-3.0.3/tools/external/fasterq-dump/cleanup_task.h <==
/*===========================================================================
*
*                            PUBLIC DOMAIN NOTICE
*               National Center for Biotechnology Information
*
*  This software/database is a "United States Government Work" under the
*  terms of the United States Copyright Act.  It was written as part of
*  the author's official duties as a United States Government employee and
*  thus cannot be copyrighted.  This software/database is freely available
*  to the public for use. The National Library of Medicine and the U.S.
*  Government have not placed any restriction on its use or reproduction.
*
*  Although all reasonable efforts have been taken to ensure the accuracy
*  and reliability of the software and data, the NLM and the U.S.
*  Government do not and cannot warrant the performance or results that
*  may be obtained by using this software or data. The NLM and the U.S.
*  Government disclaim all warranties, express or implied, including
*  warranties of performance, merchantability or fitness for any particular
*  purpose.
*
*  Please cite the author in any work or product based on this material.
*
* ===========================================================================
*
*/
#ifndef _h_fastdump_cleanup_task_
#define _h_fastdump_cleanup_task_

#ifndef _h_klib_rc_
#include <klib/rc.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

struct KFastDumpCleanupTask_t;

rc_t Make_FastDump_Cleanup_Task ( struct KFastDumpCleanupTask_t **task, bool details );

rc_t Add_File_to_Cleanup_Task ( struct KFastDumpCleanupTask_t * self, const char * filename );

rc_t Add_Directory_to_Cleanup_Task ( struct KFastDumpCleanupTask_t * self, const char * dirname );

rc_t Terminate_Cleanup_Task ( struct KFastDumpCleanupTask_t * self );
    
#ifdef __cplusplus
}
#endif

#endif /* _h_fastdump_cleanup_task_ */

==> sra-sdk_3.2.1+dfsg.orig.tar.xz: sra-tools-3.2.1/tools/external/fasterq-dump/cleanup_task.h <==
/*===========================================================================
*
*                            PUBLIC DOMAIN NOTICE
*               National Center for Biotechnology Information
*
*  This software/database is a "United States Government Work" under the
*  terms of the United States Copyright Act.  It was written as part of
*  the author's official duties as a United States Government employee and
*  thus cannot be copyrighted.  This software/database is freely available
*  to the public for use. The National Library of Medicine and the U.S.
*  Government have not placed any restriction on its use or reproduction.
*
*  Although all reasonable efforts have been taken to ensure the accuracy
*  and reliability of the software and data, the NLM and the U.S.
*  Government do not and cannot warrant the performance or results that
*  may be obtained by using this software or data. The NLM and the U.S.
*  Government disclaim all warranties, express or implied, including
*  warranties of performance, merchantability or fitness for any particular
*  purpose.
*
*  Please cite the author in any work or product based on this material.
*
* ===========================================================================
*
*/
#ifndef _h_fastdump_cleanup_task_
#define _h_fastdump_cleanup_task_

#ifndef _h_klib_rc_
#include <klib/rc.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

struct CleanupTask_t;

rc_t clt_create( struct CleanupTask_t **task, bool details );

rc_t clt_add_file( struct CleanupTask_t * self, const char * filename );

rc_t clt_add_directory( struct CleanupTask_t * self, const char * dirname );

rc_t clt_terminate( struct CleanupTask_t * self );
    
#ifdef __cplusplus
}
#endif

#endif /* _h_fastdump_cleanup_task_ */
